@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::Spool;
 # ABSTRACT: Spool des fichiers de notices
-$Koha::Contrib::Sudoc::Spool::VERSION = '2.18';
+$Koha::Contrib::Sudoc::Spool::VERSION = '2.19';
 use Moose;
 use Modern::Perl;
 use File::Copy;
@@ -156,9 +156,34 @@ sub list {
 }
 
 
+sub vide {
+    my $self = shift;
+    for ( @$dirstatus ) {
+        my ($msg, $where, $type) = @$_;
+        my @files = @{ $self->sudoc->spool->files($where, $type) };
+        next unless @files;
+        chdir $self->sudoc->root . "/var/spool/$where";
+        @files = grep {
+            my (undef, undef, undef, undef, undef, undef, undef, $size, , ,) =
+                stat($_);
+            $size == 0;
+        } @files;
+        next unless @files;
+        for my $file (@files) {
+            unlink $file;
+            say "$file: supprimé";
+        }
+    }
+}
+
+
 sub command {
     my $self = shift;
     if ( @_ ) {
+        if ($_[0] =~ /vide/i ) {
+            $self->vide();
+            return;
+        }
         for my $file (@_) {
             my $path = $self->file_path($file);
             unless ( $path ) {
@@ -189,7 +214,7 @@ Koha::Contrib::Sudoc::Spool - Spool des fichiers de notices
 
 =head1 VERSION
 
-version 2.18
+version 2.19
 
 =head1 DESCRIPTION
 
@@ -234,6 +259,10 @@ Déplace tous les fichiers de l'ILN courant de staged dans waiting
 
 Liste le contenu des répertoires du spool
 
+=head2 vide
+
+Supprime du spool tous les fichiers vides.
+
 =head2 command
 
 Sans paramètre, liste le contenu des répertoires du spool, en appelant
